@@ -248,6 +248,10 @@ def get_args():
                             dest='queuedata_url',
                             default='',
                             help='Queuedata server URL')
+    arg_parser.add_argument('--storagedata-url',
+                            dest='storagedata_url',
+                            default='',
+                            help='URL for downloading DDM end points data')
 
     # Country group
     arg_parser.add_argument('--country-group',
@@ -458,6 +462,7 @@ def set_environment_variables():
     # keep track of the server urls
     environ['PANDA_SERVER_URL'] = get_panda_server(args.url, args.port)
     environ['QUEUEDATA_SERVER_URL'] = '%s' % args.queuedata_url
+    environ['STORAGEDATA_SERVER_URL'] = '%s' % args.storagedata_url
 
 
 def wrap_up():
