@@ -5,7 +5,7 @@
 # http://www.apache.org/licenses/LICENSE-2.0
 #
 # Authors:
-# - Paul Nilsson, paul.nilsson@cern.ch, 2017-2020
+# - Paul Nilsson, paul.nilsson@cern.ch, 2017-2021
 # - Alexander Bogdanchikov, Alexander.Bogdanchikov@cern.ch, 2019-2020
 
 import os
@@ -21,7 +21,6 @@ from pilot.common.exception import PilotException, FileHandlingFailure
 from pilot.user.atlas.setup import get_asetup, get_file_system_root_path
 from pilot.user.atlas.proxy import verify_proxy
 from pilot.info import InfoService, infosys
-from pilot.util.auxiliary import is_python3
 from pilot.util.config import config
 from pilot.util.filehandling import write_file
 from pilot.util import https
@@ -495,13 +494,8 @@ def alrb_wrapper(cmd, workdir, job=None):
         cmd = cmd.replace(';;', ';')
 
         # get the proper release setup script name, and create the script if necessary
-        release_setup, cmd = create_release_setup(cmd, atlas_setup, full_atlas_setup, job.swrelease, job.imagename,
+        release_setup, cmd = create_release_setup(cmd, atlas_setup, full_atlas_setup, job.swrelease,
                                                   job.workdir, queuedata.is_cvmfs)
-        if not cmd:
-            diagnostics = 'payload setup was reset due to missing release setup in unpacked container'
-            logger.warning(diagnostics)
-            job.piloterrorcodes, job.piloterrordiags = errors.add_error_code(errors.MISSINGRELEASEUNPACKED)
-            return ""
 
         # correct full payload command in case preprocess command are used (ie replace trf with setupATLAS -c ..)
         if job.preprocess and job.containeroptions:
@@ -536,32 +530,6 @@ def alrb_wrapper(cmd, workdir, job=None):
     return cmd
 
 
-def is_release_setup(script, imagename):
-    """
-    Does the release_setup.sh file exist?
-    This check can only be made for unpacked containers. These must have the release setup file present, or setup will
-    fail. For non-unpacked containers, the function will return True and the pilot will assume that the container has
-    the setup file.
-
-    :param script: release setup script (string).
-    :param imagename: container/image name (string).
-    :return: Boolean.
-    """
-
-    if 'unpacked' in imagename:
-        if script.startswith('/'):
-            script = script[1:]
-        exists = True if os.path.exists(os.path.join(imagename, script)) else False
-        if exists:
-            logger.info('%s is present in %s', script, imagename)
-        else:
-            logger.warning('%s is not present in %s - setup has failed', script, imagename)
-    else:
-        exists = True
-        logger.info('%s is assumed to be present in %s', script, imagename)
-    return exists
-
-
 def add_asetup(job, alrb_setup, is_cvmfs, release_setup, container_script, container_options):
     """
     Add atlasLocalSetup and options to form the final payload command.
@@ -652,22 +620,16 @@ def replace_last_command(cmd, replacement):
     return cmd
 
 
-def create_release_setup(cmd, atlas_setup, full_atlas_setup, release, imagename, workdir, is_cvmfs):
+def create_release_setup(cmd, atlas_setup, full_atlas_setup, release, workdir, is_cvmfs):
     """
     Get the proper release setup script name, and create the script if necessary.
 
     This function also updates the cmd string (removes full asetup from payload command).
 
-    Note: for stand-alone containers, the function will return /release_setup.sh and assume that this script exists
-    in the container. The pilot will only create a my_release_setup.sh script for OS containers.
-
-    In case the release setup is not present in an unpacked container, the function will reset the cmd string.
-
     :param cmd: Payload execution command (string).
     :param atlas_setup: asetup command (string).
     :param full_atlas_setup: full asetup command (string).
     :param release: software release, needed to determine Athena environment (string).
-    :param imagename: container image name (string).
     :param workdir: job workdir (string).
     :param is_cvmfs: does the queue have cvmfs? (Boolean).
     :return: proper release setup name (string), updated cmd (string).
@@ -690,94 +652,7 @@ def create_release_setup(cmd, atlas_setup, full_atlas_setup, release, imagename,
     except FileHandlingFailure as exc:
         logger.warning('exception caught: %s', exc)
 
-    # reset cmd in case release_setup.sh does not exist in unpacked image (only for those containers)
-    if imagename and release and release != 'NULL':
-        cmd = cmd.replace(';;', ';') if is_release_setup(release_setup_name, imagename) else ''
-
-    return release_setup_name, cmd
-
-
-def create_release_setup_old(cmd, atlas_setup, full_atlas_setup, release, imagename, workdir, is_cvmfs):
-    """
-    Get the proper release setup script name, and create the script if necessary.
-
-    This function also updates the cmd string (removes full asetup from payload command).
-
-    Note: for stand-alone containers, the function will return /release_setup.sh and assume that this script exists
-    in the container. The pilot will only create a my_release_setup.sh script for OS containers.
-
-    In case the release setup is not present in an unpacked container, the function will reset the cmd string.
-
-    :param cmd: Payload execution command (string).
-    :param atlas_setup: asetup command (string).
-    :param full_atlas_setup: full asetup command (string).
-    :param release: software release, needed to determine Athena environment (string).
-    :param imagename: container image name (string).
-    :param workdir: job workdir (string).
-    :param is_cvmfs: does the queue have cvmfs? (Boolean).
-    :return: proper release setup name (string), updated cmd (string).
-    """
-
-    release_setup_name = get_release_setup_name(release, imagename)
-
-    # note: if release_setup_name.startswith('/'), the pilot will NOT create the script
-    if not release_setup_name.startswith('/'):
-        # extracted_asetup should be written to 'my_release_setup.sh' and cmd to 'container_script.sh'
-        content = 'echo \"INFO: sourcing %s inside the container. ' \
-                  'This should not run if it is a ATLAS standalone container\"' % release_setup_name
-        if is_cvmfs:
-            content, cmd = extract_full_atlas_setup(cmd, atlas_setup)
-            if not content:
-                content = full_atlas_setup
-        if not content:
-            logger.debug(
-                'will create an empty (almost) release setup file since asetup could not be extracted from command')
-        logger.debug('command to be written to release setup file:\n\n%s:\n\n%s\n', release_setup_name, content)
-        try:
-            write_file(os.path.join(workdir, release_setup_name), content, mute=False)
-        except FileHandlingFailure as exc:
-            logger.warning('exception caught: %s', exc)
-    else:
-        # reset cmd in case release_setup.sh does not exist in unpacked image (only for those containers)
-        cmd = cmd.replace(';;', ';') if is_release_setup(release_setup_name, imagename) else ''
-
-    # add the /srv for OS containers
-    if not release_setup_name.startswith('/'):
-        release_setup_name = os.path.join('/srv', release_setup_name)
-
-    return release_setup_name, cmd
-
-
-def get_release_setup_name(release, imagename):
-    """
-    Return the file name for the release setup script.
-
-    NOTE: the /srv path will only be added later, in the case of OS containers.
-
-    For OS containers, return config.Container.release_setup (my_release_setup.sh);
-    for stand-alone containers (user defined containers, ie when --containerImage or job.imagename was used/set),
-    return '/release_setup.sh'. release_setup.sh will NOT be created for stand-alone containers.
-    The pilot will specify /release_setup.sh only when jobs use the Athena environment (ie has a set job.swrelease).
-
-    :param release: software release (string).
-    :param imagename: container image name (string).
-    :return: release setup file name (string).
-    """
-
-    if imagename and release and release != 'NULL':
-        # stand-alone containers (script is assumed to exist inside image/container so will ignore this /srv/my_release_setup.sh)
-        release_setup_name = '/srv/my_release_setup.sh'
-        # stand-alone containers (script is assumed to exist inside image/container)
-        # release_setup_name = '/release_setup.sh'
-    else:
-        # OS containers (script will be created by pilot)
-        release_setup_name = config.Container.release_setup
-        if not release_setup_name:
-            release_setup_name = 'my_release_setup.sh'
-
-    # note: if release_setup_name.startswith('/'), the pilot will NOT create the script
-
-    return release_setup_name
+    return release_setup_name, cmd.replace(';;', ';')
 
 
 ## DEPRECATED, remove after verification with user container job
@@ -980,14 +855,12 @@ def get_middleware_container_script(middleware_container, cmd, asetup=False, lab
     if 'rucio' in middleware_container:
         content = sitename + 'python3 %s ' % cmd  # only works with python 3
     else:
-        content = ''
-        if is_python3():
-            content += 'export ALRB_LOCAL_PY3=YES; '
+        content = 'export ALRB_LOCAL_PY3=YES; '
         if asetup:  # export ATLAS_LOCAL_ROOT_BASE=/cvmfs/..;source ${ATLAS_LOCAL_ROOT_BASE}/user/atlasLocalSetup.sh --quiet;
             content += get_asetup(asetup=False)
         if label == 'stagein' or label == 'stageout':
             content += sitename + 'lsetup rucio davix xrootd; '
-            content += 'python3 %s ' % cmd if is_python3() else 'python %s' % cmd
+            content += 'python3 %s ' % cmd
         else:
             content += cmd
     if not asetup:
